@@ -52,7 +52,9 @@ class WsConnection:
     async def handle_publications(self, websocket: WebSocketServerProtocol, _path: str) -> None:
         while True:
             message = await self.rpc_handler.get_next_subscribed_message()
-            await websocket.send(message.to_jsons(self.rpc_handler.case))
+            await websocket.send(
+                self.rpc_handler.serialize_cached_subscription_message(message)
+            )
 
     async def close(self) -> None:
         self.rpc_handler.close()
@@ -69,5 +71,10 @@ class WsConnection:
         if alive_handler is not None:
             alive_handler.cancel()
 
+        # cleanup to avoid circular reference and allow immediate GC.
+        self.request_handler = None
+        self.publish_handler = None
+        self.alive_handler = None
+
         await self.ws.close()
 
